/**
 * Implements the basic functionality of a frog, and represents it
 * using simple graphical elements.
 * 
 * @author Liam Keliher (based on 2004 code by R. Rosebrugh) 
 * @version 2005-10-02
 */
public class Frog
{
    private String name;  
    private Triangle head;
    private Circle leftEye, rightEye;
    private int vPos, hPos;


    /**
     * Constructor for default objects of class Frog.
     */
    public Frog()
    {
        name = "Kermit";
        head = new Triangle();
        head.changeSize(35, 105);
        // Move head from initial position (50, 15) to default (150, 100)
        head.moveHorizontal(100);
        head.moveVertical(85);
        hPos = 150;
        vPos = 100;

        leftEye = new Circle();
        leftEye.changeSize(21);
        leftEye.changeColor("black");
        // Move left eye from initial position (20, 60)
        leftEye.moveHorizontal(100);
        leftEye.moveVertical(45);

        rightEye = new Circle();
        rightEye.changeSize(21);
        rightEye.changeColor("black");
        // Move right eye from initial position (20, 60)
        rightEye.moveHorizontal(140);
        rightEye.moveVertical(45);
    } // constructor Frog()


    /**
     * Constructor with parameters for objects of class Frog.
     * 
     * @param inName  name to be given to frog
     * @param inHoriz  initial horizontal position
     * @param inVert  initial vertical position
     */
    public Frog(String inName, int inHoriz, int inVert)
    {
        name = inName;

        // Set the position if inputs are valid, otherwise use default values
        if ((inHoriz >= 52) && (inHoriz <= 247) && (inVert >= 0) && (inVert <= 265))
        {
            hPos = inHoriz;
            vPos = inVert;
        } // if
        else
        {
            System.out.println("Frog partly off page -- using default position");
            hPos = 150;
            vPos = 100;
        } // else

        head = new Triangle();
        head.changeSize(35, 105);
        // Move head from initial position (50, 15) to default (150, 100)
        head.moveHorizontal(hPos - 50);
        head.moveVertical(vPos - 15);

        leftEye = new Circle();
        leftEye.changeSize(21);
        leftEye.changeColor("black");
        // Move left eye from initial position (20, 60)
        leftEye.moveHorizontal(hPos - 50);
        leftEye.moveVertical(vPos - 55);

        rightEye = new Circle();
        rightEye.changeSize(21);
        rightEye.changeColor("black");
        // Move right eye from initial position (20, 60)
        rightEye.moveHorizontal(hPos - 10);
        rightEye.moveVertical(vPos - 55);
    } // constructor Frog(String,int,int)


     /**
     * Returns the frog's name.
     * 
     * @return the name string
     */
    public String getName()
    {   
        return name;
    } // getName()


    /**
     * Makes the frog visible.
     */
    public void makeFrogVisible()
    {
        head.makeVisible();
        leftEye.makeVisible();
        rightEye.makeVisible();
    } // makeFrogVisible()


    /**
     * Erases the frog.
     */
    public void makeFrogInvisible()
    {
        head.makeInvisible();
        leftEye.makeInvisible();
        rightEye.makeInvisible();
    } // makeFrogInvisible()


    /**
     * Moves the frog left by 'dist' pixels, stopping at the left wall
     * if 'dist' is too large.
     * 
     * @param dist the distance to move left -- must be positive to have effect
     */
    public void frogLeft(int dist)
    {
        int actualDist;
        if (dist > 0)
        {
            actualDist = dist;
            if ((hPos - 52) < dist)
            {
                actualDist = hPos - 52;
            } // if
            head.moveHorizontal(-actualDist);
            leftEye.moveHorizontal(-actualDist);
            rightEye.moveHorizontal(-actualDist);
            hPos = hPos - actualDist;
        } // if
    } // frogLeft(int)


    /**
     * Moves the frog right by 'dist' pixels, stopping at the right wall
     * if 'dist' is too large.
     * 
     * @param dist the distance to move right -- must be positive to have effect
     */
    public void frogRight(int dist)
    {
        int actualDist;
        if (dist > 0)
        {
            actualDist = dist;
            if ((299 - (hPos + 52)) < dist)
            {
                actualDist = 299 - (hPos + 52);
            } // if
            head.moveHorizontal(actualDist);
            leftEye.moveHorizontal(actualDist);
            rightEye.moveHorizontal(actualDist);
            hPos = hPos + actualDist;
        } // if
    } // frogRight(int)


    /**
     * Moves the frog upward by 'height' pixels, drawing the frog after
     * each move of 1 pixel;  returns frog to initial level in same way.
     * Frog only jumps as high as ceiling if 'height' is too large.
     * 
     * @param height  the number of pixels frog is to jump upward -- must be positive
     */
    public void jump(int height)
    {
        int i, jumpHeight;

        if (height > 0)
        {
            jumpHeight = height;
            if (height > vPos)
            {
                jumpHeight = vPos;
            } // if
            
            // Upward motion
            for (i = 0; i < jumpHeight; i++)
            {
                head.moveVertical(-1);
                leftEye.moveVertical(-1);
                rightEye.moveVertical(-1);
            } // for i

            // Downward motion
            for (i = 0; i < jumpHeight; i++)
            {
                head.moveVertical(1);
                leftEye.moveVertical(1);
                rightEye.moveVertical(1);
            } // for i
        } // if
    } // jump(int)

}  // class Frog
